pub struct FrameworkBuilder<U, E> { /* private fields */ }Expand description
A builder to configure a framework.
If one of the following required values is missing, the builder will panic on start:
Implementations
Sourceimpl<U, E> FrameworkBuilder<U, E>
impl<U, E> FrameworkBuilder<U, E>
Sourcepub fn setup<F>(self, setup: F) -> Self
pub fn setup<F>(self, setup: F) -> Self
Sets the setup callback which also returns the user data struct.
Sourcepub fn options(self, options: FrameworkOptions<U, E>) -> Self
pub fn options(self, options: FrameworkOptions<U, E>) -> Self
Configure framework options
Sourcepub fn initialize_owners(self, initialize_owners: bool) -> Self
pub fn initialize_owners(self, initialize_owners: bool) -> Self
Whether to add this bot application’s owner and team members to
crate::FrameworkOptions::owners automatically
true by default